import { defineComponent, reactive } from 'vue';
import styles from './index.module.less';
import dingPng from '../../images/protocol/dingPng.png';
import moveTop from '../../images/protocol/moveTop.png';
import closeAble from '../../images/protocol/closeAble.png';
import { NSpace, NButton, NScrollbar } from 'naive-ui';

export default defineComponent({
  name: 'add-courseware-protocol',
  emits: ['close', 'confirm'],
  setup(props, { emit }) {
    const forms = reactive({
      status: false,
      protocolShow: false // 是否显示协议
    });
    return () => (
      <div class={styles.protocolModal}>
        <img src={dingPng} class={styles.dingPng} alt="" />
        {!forms.protocolShow ? (
          <div class={styles.downMove}>
            <img src={moveTop} class={styles.downMoveBg} alt="" />
            <img
              src={closeAble}
              class={styles.closeAble}
              onClick={() => {
                // showModalMask.value = false;
                // checkAuthShow();
                emit('close');
              }}
              alt=""
            />
            <h2>课件公开须知</h2>
            <p>
              公开课件后，您课件中的资源及作业都可被其他教师查看、使用，具体信息请查看服务协议
            </p>

            <div
              class={styles.protocolGroup}
              onClick={() => {
                forms.status = !forms.status;
              }}>
              <i
                class={[
                  styles.checkbox,
                  forms.status && styles.checkboxActive
                ]}></i>
              <p>
                我已阅读并同意
                <span
                  onClick={(e: any) => {
                    e.stopPropagation();
                    forms.protocolShow = true;
                  }}>
                  《音乐数字课堂课件与作业公开服务协议》
                </span>
              </p>
            </div>

            <NSpace style={{ padding: '25px 0 0 0' }} justify="center">
              <NButton
                class={styles.cancelBtn}
                round
                type="default"
                onClick={() => emit('close')}>
                取消
              </NButton>
              <NButton
                class={styles.submitAppBtn}
                bordered={false}
                round
                type="primary"
                disabled={!forms.status}
                onClick={() => {
                  emit('confirm');
                }}>
                确定
              </NButton>
            </NSpace>
          </div>
        ) : (
          <div class={styles.protocolSection}>
            <img src={moveTop} class={styles.downMoveBg} alt="" />
            <img
              src={closeAble}
              class={styles.closeAble}
              onClick={() => {
                // showModalMask.value = false;
                // checkAuthShow();
                forms.protocolShow = false;
              }}
              alt=""
            />
            <h2>《音乐数字课堂课件与作业公开服务协议》</h2>

            <NScrollbar style={{ maxHeight: '45vh' }}>
              <div class={styles.protocolContent}>
                <p style={{ paddingTop: '0' }}>欢迎使用音乐数字课堂！</p>
                <p>重要须知</p>
                武汉酷乐秀网络科技有限公司（以下统称“平台方”，或称“我们”），在此特别提醒，为使用音乐数字课堂（包括手机端、网页端等，以下称“软件”或“平台”）与相关信息化教育产品、内容及服务，您务必仔细阅读、充分理解并遵守《音乐数字课堂课件与作业公开服务协议》（以下简称“本协议”）中各项条款，包括免除或者限制责任的条款，并选择接受或不接受。本协议所述服务条款构成您（个人或者单位、组织、团体等）使用平台方提供的相关服务（以下简称“该服务”）的先决条件。若您不接受本协议中所述服务条款或其后对协议条款的修改，您应不使用或主动取消平台方提供的相关服务。
                您自愿使用平台方提供的网络存储空间进行培训课件与作业及相关智力成果的上传及传播服务。如果您未满18周岁，请在法定监护人的陪同下阅读本协议。
                <br />
                本协议是您（或称“用户”，指注册、登录、使用、浏览本服务的个人或组织）与平台方之间关于音乐数字课堂与相关信息化教育产品、内容及服务所订立的协议。
                <br />
                <p>1 权利声明</p>
                音乐数字课堂由武汉酷乐秀网络科技有限公司（以下简称“酷乐秀”）独立开发，一切知识产权以及音乐数字课堂自有的所有信息内容包括但不限于：文字表述及其组合、图标、图饰、图像、图表、色彩、界面设计、版面框架、有关数据、附加程序、印刷材料或电子文档等均为酷乐秀所有，受著作权法和国际著作权条约以及其他知识产权法律法规的保护。
                <br />
                音乐数字课堂由武汉酷乐秀网络科技有限公司（以下简称“音乐数字课堂”）提供运营管理服务。
                <br />
                <p>2 服务说明 </p>
                2.1
                您可以通过音乐数字课堂主页【网址：https://kt.colexiu.com/classroom-admin/#/login】、手机客户端（及其他由音乐数字课堂运营的任何网站）、音乐数字课堂公众号，访问音乐数字课堂并使用相关服务。
                <br />
                2.2
                您知悉并同意，在注册成为音乐数字课堂用户或使用本服务时，需提供一些必要信息，包括但不限于手机号码、头像等。若国家法律法规或政策有特殊规定的，平台方会根据相关特殊规定要求您提供相关信息，如真实的身份信息等，若您提供的信息不完整，您将无法使用本服务或本服务中的相关功能，由此为您带来不便或损失的，平台方完全免责。如个人信息发生变更，您有权随时与平台方联系并要求修改相关个人信息。在您向平台方提出前述删除请求前，平台方可在本协议约定范围内合理利用相关个人信息。
                <br />
                您应承诺合法使用平台方提供的服务，您使用该服务的行为应符合当地的法律法规及政策的要求，否则由此带来的责任由您自行承担。
                <br />
                <p>3 权利授予 </p>
                3.1
                您理解并同意，您将课件与作业及相关智力成果上传至音乐数字课堂，即视为您授予了平台方无期限限制的、全球范围内的、不可撤销的信息网络传播权和其他形式的使用权。为了更好地对课件与作业进行宣传和推广，平台方可以将上述权利转让或者转授予给其关联公司或者合作伙伴，而无须征得您的同意。您如果不同意上述条款，请不要将作品上传至音乐数字课堂。
                <br />
                3.2
                平台方仅对您提交的资料和信息进行审核，并不对您的主体资质和上传的课件与作业内容的真实性、正确性、合法性承担任何责任或提供任何担保。
                <br />
                3.3
                如果任何第三方侵犯音乐数字课堂用户相关的权利，用户同意授权平台方或其指定的代理人代表平台方自身或用户对该第三方提出警告、投诉、发起行政执法、诉讼、进行上诉，或谈判和解，并且用户同意在平台方认为必要的情况下参与共同维权。
                <br />
                <p>4 权利限制 </p>
                4.1
                平台方通过音乐数字课堂所提供的服务，均限于在音乐数字课堂平台内使用，禁止任何以恶意破解等非法手段将音乐数字课堂内的服务与音乐数字课堂平台分离的行为，否则，由此引起的一切后果由行为人负责，平台方将保留依法追究行为人法律责任的权利。
                <br />
                4.2
                未经平台方书面同意，您不得将已上传至音乐数字课堂平台上的培训课件与作业的任何资料文件直接、间接或经修改后提供给任何第三方。
                <br />
                4.3
                保留权利：本协议未明示许可的其他一切权利仍归平台方所有，您使用其他权利时必须获得平台方的书面同意。
                <br />
                4.4
                除本协议有明确规定外，本协议并未对平台方其他服务规定相关的服务条款，对于这些服务可能有单独的服务条款加以规范，请您在使用有关服务时另行了解与确认。如您使用该服务，视为对相关服务条款的接受。
                <br />
                <p>5 用户使用须知</p>
                5.1
                您承诺您具有履行本协议义务的权利能力及资格，因您自身职务或职业要求导致本协议无法履行或合同目的无法实现的，您应当及时通知平台方，并共同协商解决办法，以保证将事件影响性降到最低。
                <br />
                5.2
                您保证，您上传的课件与作业所涉的创意、脚本、资料、课件与作业等全部文件资料不违反国家相关法律法规、不侵犯第三方权益，且平台方按照约定行使授权内容的相关权利不会侵犯任何第三方的合法权益，也无须另行取得任何第三方的同意，更无须对任何第三方承担责任。如您违反前述保证，平台方有权采取包括但不限于删除相关课件与作业内容、中止或终止向您提供服务等措施。如您上传的课件与作业侵犯了第三方的合法权利，第三方向平台方提出举报，平台方有权删除相关的内容。当权利人发现音乐数字课堂上相关课件与作业侵犯其合法权益时，权利人可向平台方举报，平台方将根据中国法律法规和规范性文件的规定采取移除相关内容等合理措施。
                <br />
                5.3 您保证上传的课件与作业中不含以下内容：
                <br />
                <div class={styles.child}>
                  1. 反对宪法所确定的基本原则；
                  <br />
                  2. 危害国家安全，泄漏国家秘密，颠覆国家政权，破坏国家统一；
                  <br />
                  3. 损害国家荣誉和利益； <br />
                  4. 煽动民族仇恨、民族歧视，破坏民族团结；
                  <br />
                  5. 破坏国家宗教政策，宣扬邪教和封建迷信；
                  <br />
                  6. 散布谣言，扰乱社会秩序，破坏社会稳定；
                  <br />
                  7. 散布淫秽、色情、赌博、暴力、凶杀、恐怖或教唆犯罪；
                  <br />
                  8. 侮辱或者诽谤他人，侵害他人合法权益；
                  <br />
                  9. 含有法律、行政法规严令禁止的其他内容。
                  <br />
                </div>
                5.4
                上述承诺与保证不受本协议期限的限制，您违反上述任一的保证与承诺的，平台方有权即时解除本协议并要求您承担由此产生的全部责任。
                <br />
                <p>6 隐私政策 </p>
                6.1 目的
                为改善平台方服务，提升用户体验，在您使用音乐数字课堂时，平台方可能对您使用音乐数字课堂的使用信息进行统计与分析，例如：平台方会根据您上传并通过审核的某单元的课件与作业数量显示您在该单元全国范围内的排名，同时显示您的头像、昵称信息及通过审核的课件与作业数量。平台方将采取必要的保护措施，以保护您的相关信息。您可以选择不提供或只提供部分信息，但平台方可能将无法为您提供完整的产品功能或服务。
                <p>7 免责与责任限制</p>
                7.1
                音乐数字课堂不含有任何旨在破坏您计算机数据和获取您隐私信息的恶意代码。音乐数字课堂经过详细的测试，但不能保证与所有的软硬件系统完全兼容，不能保证音乐数字课堂完全没有错误。如果出现不兼容及软件错误的情况，您可拨打技术支持电话将情况报告平台方，以获得技术支持。如果无法解决兼容性问题，您可以删除音乐数字课堂。由此给您造成损失的，您同意平台方免责。
                <br />
                7.2
                在适用法律允许的最大范围内，对因使用或不能使用音乐数字课堂所产生的损害及风险，包括但不限于直接或间接的个人损害、商业赢利的丧失、贸易中断、商业信息的丢失或任何其它经济损失，平台方不承担任何责任。
                <br />
                7.3
                对于因电信系统或互联网网络故障、计算机故障或病毒、信息损坏或丢失、计算机系统问题或其它任何不可抗力原因而产生损失，平台方不承担任何责任。
                <br />
                7.4
                您知悉并同意，为实现部分软件功能，平台方有权将您在使用该服务过程当中产生的部分或全部数据信息，上传、保存至第三方云服务存储器，并根据您发出的功能指令需求，自行调取相关数据信息。因第三方云服务发生中断等功能障碍事故导致平台方无法正常提供服务的，平台方会尽其商业上的合理努力负责协调解决，但由此给您造成损失的，您同意平台方免责。
                <br />
                7.5
                您违反本协议规定，对平台方造成损害的。平台方有权采取包括但不限于中断使用许可、停止提供服务、限制使用、法律追究等措施。
                <br />
                <p>8 法律及争议解决</p>
                8.1 本协议适用中华人民共和国法律。
                <br /> 8.2
                因本协议引起的或与本协议有关的任何争议，各方应友好协商解决；协商不成的，任何一方均可将有关争议提交至平台方所在地有管辖权的人民法院管辖。
                <br />
                <p>9 其他条款</p>
                9.1
                如果本协议中的任何条款无论因何种原因完全或部分无效或不具有执行力，或违反任何适用的法律，则该条款被视为删除，但本协议的其余条款仍有效并且具有约束力。
                <br />
                9.2
                如果本协议中的任何条款与音乐数字课堂中某具体软件的协议条款相矛盾的，以该具体软件的协议条款为准。
                <br />
                平台方有权随时根据有关法律、法规的变化以及公司经营状况和经营策略的调整等修改本协议。修改后的协议会在平台方指定网站上公布，并随附于新版音乐数字课堂。当发生有关争议时，以最新的协议文本为准。如果不同意改动的内容，您可以自行删除音乐数字课堂。如果您继续使用音乐数字课堂，则视为您接受本协议的变动。
                <br />
                至此，用户已经详细阅读并已理解本协议，并同意严格遵守各条款和条件。如果用户对本《协议》有任何疑问或者希望获得与本软件相关的任何信息，请按下列地址和方式与酷乐秀联系，酷乐秀将在15日内答复用户。
                <br />
                技术支持方：武汉酷乐秀网络科技有限公司
                <br />
                运营方：武汉酷乐秀网络科技有限公司
              </div>
            </NScrollbar>

            <NSpace style={{ padding: '25px 0 0 0' }} justify="center">
              <NButton
                class={styles.cancelBtn}
                round
                type="default"
                onClick={() => {
                  forms.protocolShow = false;
                }}>
                取消授权
              </NButton>
              <NButton
                class={styles.submitAppBtn}
                bordered={false}
                round
                type="primary"
                onClick={() => {
                  forms.protocolShow = false;
                  forms.status = true;
                }}>
                同意授权
              </NButton>
            </NSpace>
          </div>
        )}
      </div>
    );
  }
});
